==> jc-1.4.0.tar.gz: java/lang/VMProcess__24ProcessThread.h <==
// class java.lang.VMProcess$ProcessThread

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread
// @dep_class f2679ec9231c42db java_lang_VMProcess__24ProcessThread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_java_lang_VMProcess__24ProcessThread_H_
#define _JC_java_lang_VMProcess__24ProcessThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_VMProcess$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_java_lang_VMProcess__24ProcessThread$sub_refs	_jc_java_lang_VMProcess__24ProcessThread$sub_refs;
typedef struct _jc_java_lang_VMProcess__24ProcessThread$sub_nonrefs	_jc_java_lang_VMProcess__24ProcessThread$sub_nonrefs;
typedef struct _jc_java_lang_VMProcess__24ProcessThread$refs	_jc_java_lang_VMProcess__24ProcessThread$refs;
typedef struct _jc_java_lang_VMProcess__24ProcessThread$nonrefs	_jc_java_lang_VMProcess__24ProcessThread$nonrefs;
typedef struct _jc_java_lang_VMProcess__24ProcessThread$object	_jc_java_lang_VMProcess__24ProcessThread$object;

typedef struct _jc_java_lang_VMProcess__24ProcessThread$fields_struct	_jc_java_lang_VMProcess__24ProcessThread$fields_struct;
typedef const struct _jc_java_lang_VMProcess__24ProcessThread$vmethods	_jc_java_lang_VMProcess__24ProcessThread$vmethods;
typedef const struct _jc_java_lang_VMProcess__24ProcessThread$vtable	_jc_java_lang_VMProcess__24ProcessThread$vtable;
typedef const struct _jc_java_lang_VMProcess__24ProcessThread$vtype	_jc_java_lang_VMProcess__24ProcessThread$vtype;

// Class fields structure
struct _jc_java_lang_VMProcess__24ProcessThread$fields_struct {
	jint	MAX__5fREAP__5fDELAY;
};
extern _jc_java_lang_VMProcess__24ProcessThread$fields_struct _jc_java_lang_VMProcess__24ProcessThread$class_fields;

// Constructors
extern void _jc_java_lang_VMProcess__24ProcessThread$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *);

// Virtual methods
extern void _jc_java_lang_VMProcess__24ProcessThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *);
extern void _jc_java_lang_VMProcess__24ProcessThread$method$spawn$75fac29a5883ad20(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *, struct _jc_java_lang_VMProcess$object *);
extern void _jc_java_lang_VMProcess__24ProcessThread$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_VMProcess__24ProcessThread$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_java_lang_VMProcess__24ProcessThread$method_info$spawn$75fac29a5883ad20;
extern _jc_method _jc_java_lang_VMProcess__24ProcessThread$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_lang_VMProcess__24ProcessThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *);
	void	(*spawn$75fac29a5883ad20)(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *, struct _jc_java_lang_VMProcess$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *);
};

// Vtable
struct _jc_java_lang_VMProcess__24ProcessThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_java_lang_VMProcess__24ProcessThread$vmethods	java_lang_VMProcess__24ProcessThread;
};

// Vtype
struct _jc_java_lang_VMProcess__24ProcessThread$vtype {
	_jc_type			type;
	_jc_java_lang_VMProcess__24ProcessThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMProcess__24ProcessThread$sub_refs {
	struct _jc_java_util_HashMap$object	*activeMap;
};

// Reference instance fields (object)
struct _jc_java_lang_VMProcess__24ProcessThread$refs {
    _jc_java_lang_VMProcess__24ProcessThread$sub_refs	java_lang_VMProcess__24ProcessThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMProcess__24ProcessThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMProcess__24ProcessThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_java_lang_VMProcess__24ProcessThread$sub_nonrefs	java_lang_VMProcess__24ProcessThread;
};

// Object instance structure
struct _jc_java_lang_VMProcess__24ProcessThread$object {
	_jc_java_lang_VMProcess__24ProcessThread$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMProcess__24ProcessThread$vtype	*vtype;
	_jc_java_lang_VMProcess__24ProcessThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMProcess__24ProcessThread$vtype _jc_java_lang_VMProcess__24ProcessThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMProcess__24ProcessThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMProcess__24ProcessThread$class_object;

#endif	/* _JC_java_lang_VMProcess__24ProcessThread_H_ */

==> jc-1.4.6.tar.gz: java/lang/VMProcess__24ProcessThread.h <==
// class java.lang.VMProcess$ProcessThread

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread
// @dep_class f2679ec9231c42db java_lang_VMProcess__24ProcessThread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_java_lang_VMProcess__24ProcessThread_H_
#define _JC_java_lang_VMProcess__24ProcessThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_VMProcess$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_java_lang_VMProcess__24ProcessThread$sub_refs	_jc_java_lang_VMProcess__24ProcessThread$sub_refs;
typedef struct _jc_java_lang_VMProcess__24ProcessThread$sub_nonrefs	_jc_java_lang_VMProcess__24ProcessThread$sub_nonrefs;
typedef struct _jc_java_lang_VMProcess__24ProcessThread$refs	_jc_java_lang_VMProcess__24ProcessThread$refs;
typedef struct _jc_java_lang_VMProcess__24ProcessThread$nonrefs	_jc_java_lang_VMProcess__24ProcessThread$nonrefs;
typedef struct _jc_java_lang_VMProcess__24ProcessThread$object	_jc_java_lang_VMProcess__24ProcessThread$object;

typedef struct _jc_java_lang_VMProcess__24ProcessThread$fields_struct	_jc_java_lang_VMProcess__24ProcessThread$fields_struct;
typedef const struct _jc_java_lang_VMProcess__24ProcessThread$vmethods	_jc_java_lang_VMProcess__24ProcessThread$vmethods;
typedef const struct _jc_java_lang_VMProcess__24ProcessThread$vtable	_jc_java_lang_VMProcess__24ProcessThread$vtable;
typedef const struct _jc_java_lang_VMProcess__24ProcessThread$vtype	_jc_java_lang_VMProcess__24ProcessThread$vtype;

// Class fields structure
struct _jc_java_lang_VMProcess__24ProcessThread$fields_struct {
	jint	MAX__5fREAP__5fDELAY;
};
extern _jc_java_lang_VMProcess__24ProcessThread$fields_struct _jc_java_lang_VMProcess__24ProcessThread$class_fields;

// Constructors
extern void _jc_java_lang_VMProcess__24ProcessThread$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_lang_VMProcess__24ProcessThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMProcess__24ProcessThread$method$spawn$75fac29a5883ad20(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *, struct _jc_java_lang_VMProcess$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMProcess__24ProcessThread$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_VMProcess__24ProcessThread$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_java_lang_VMProcess__24ProcessThread$method_info$spawn$75fac29a5883ad20;
extern _jc_method _jc_java_lang_VMProcess__24ProcessThread$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_lang_VMProcess__24ProcessThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *) _JC_JCNI_ATTR;
	void	(*spawn$75fac29a5883ad20)(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *, struct _jc_java_lang_VMProcess$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_VMProcess__24ProcessThread$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_VMProcess__24ProcessThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_java_lang_VMProcess__24ProcessThread$vmethods	java_lang_VMProcess__24ProcessThread;
};

// Vtype
struct _jc_java_lang_VMProcess__24ProcessThread$vtype {
	_jc_type			type;
	_jc_java_lang_VMProcess__24ProcessThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMProcess__24ProcessThread$sub_refs {
	struct _jc_java_util_HashMap$object	*activeMap;
};

// Reference instance fields (object)
struct _jc_java_lang_VMProcess__24ProcessThread$refs {
    _jc_java_lang_VMProcess__24ProcessThread$sub_refs	java_lang_VMProcess__24ProcessThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMProcess__24ProcessThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMProcess__24ProcessThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_java_lang_VMProcess__24ProcessThread$sub_nonrefs	java_lang_VMProcess__24ProcessThread;
};

// Object instance structure
struct _jc_java_lang_VMProcess__24ProcessThread$object {
	_jc_java_lang_VMProcess__24ProcessThread$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMProcess__24ProcessThread$vtype	*vtype;
	_jc_java_lang_VMProcess__24ProcessThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMProcess__24ProcessThread$vtype _jc_java_lang_VMProcess__24ProcessThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMProcess__24ProcessThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMProcess__24ProcessThread$class_object;

#endif	/* _JC_java_lang_VMProcess__24ProcessThread_H_ */
